@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the positive/negative sentiment of text
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moo;
 use strictures 2;
@@ -117,10 +117,33 @@ sub nrc_sentiment {
 
         my @words = split /\s+/, $sentence;
 
+        my $initial = {
+            anger        => 0,
+            anticipation => 0,
+            disgust      => 0,
+            fear         => 0,
+            joy          => 0,
+            negative     => 0,
+            positive     => 0,
+            sadness      => 0,
+            surprise     => 0,
+            trust        => 0,
+        };
+
+        my $score;
+
         for my $word ( @words ) {
-            push @scores, exists $emotion->wordlist->{$word}
-                ? $emotion->wordlist->{$word} : $null_state;
+            if ( exists $emotion->wordlist->{$word} ) {
+                for my $key ( keys %{ $emotion->wordlist->{$word} } ) {
+                    $score->{$key} += $emotion->wordlist->{$word}{$key};
+                }
+            }
         }
+
+        $score = $initial
+            unless $score;
+
+        push @scores, $score;
     }
 
     $self->nrc_scores( \@scores );
@@ -140,7 +163,7 @@ Lingua::EN::Opinion - Measure the positive/negative sentiment of text
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -213,7 +236,7 @@ in the analyzed score.
 
 =head2 nrc_sentiment()
 
-Compute the NRC sentiment of the given text.
+Compute the NRC sentiment of the given text by sentences.
 
 This is given by a 0/1 list of these 10 emotional elements:
 
